pyngrok Coverage Report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
pyngrok/__init__.py | 0 | 0 | 0 | 100.00%
pyngrok/conf.py | 43 | 4 | 0 | 90.70%
pyngrok/exception.py | 28 | 0 | 0 | 100.00%
pyngrok/installer.py | 147 | 8 | 4 | 94.56%
pyngrok/log.py | 31 | 0 | 6 | 100.00%
pyngrok/ngrok.py | 222 | 28 | 6 | 87.39%
pyngrok/process.py | 190 | 11 | 9 | 94.21%
Total | 661 | 51 | 25 | 92.28%

No items found using the specified filter.